@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.102 2006/01/12 05:48:25 philipl Exp $ */
+/* $Id: gweather-applet.c,v 1.104 2006/01/30 06:55:34 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -25,6 +25,7 @@
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
+#include <libnotify/notification.h>
 #endif
 
 #include "gweather.h"
@@ -219,7 +220,15 @@ static void pref_cb (BonoboUIComponent *uic,
 		     GWeatherApplet    *gw_applet,
 		     const gchar       *verbname)
 {
-    gweather_pref_run (gw_applet);
+   if (gw_applet->pref_dialog) {
+	gtk_window_present (GTK_WINDOW (gw_applet->pref_dialog));
+   } else {
+	gw_applet->pref_dialog = gweather_pref_new(gw_applet);
+	g_object_add_weak_pointer(G_OBJECT(gw_applet->pref_dialog),
+				  (gpointer *)&(gw_applet->pref_dialog));
+	/* XXX: This should not be necessary */
+	gtk_widget_show_all (gw_applet->pref_dialog);
+   }
 }
 
 static void details_cb (BonoboUIComponent *uic,
@@ -250,8 +259,8 @@ static const BonoboUIVerb weather_applet_menu_verbs [] = {
 static void
 applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
 {
-    if (gw_applet->pref)
-       gtk_widget_destroy (gw_applet->pref);
+    if (gw_applet->pref_dialog)
+       gtk_widget_destroy (gw_applet->pref_dialog);
 
     if (gw_applet->about_dialog)
 	gtk_widget_destroy (gw_applet->about_dialog);
@@ -418,41 +427,48 @@ update_finish (WeatherInfo *info, gpointer data)
 	    gweather_dialog_update(gw_applet);
 
 #ifdef HAVE_LIBNOTIFY
-            conf = gconf_client_get_default ();
-            if (!gconf_client_get_bool (conf, "/apps/panel/applets/weather/use_libnotify", NULL))
-            {
-                g_object_unref (conf);
-                return;
-            }
-            g_object_unref (conf);
+	    if (panel_applet_gconf_get_bool (gw_applet->applet,
+				    "show_notifications", NULL))
+	    {
+		    NotifyNotification *n;
+	            
+		    /* Show notifications if possible */
+	            if (!notify_is_initted ())
+	                notify_init (_("Weather Forecast"));
 
-            /* Show notifications if possible */
-            if (!notify_is_initted ())
-                if (!notify_init (_("Weather Forecast")))
-                    return;
-
-            /* Show notification */
-            message = g_strdup_printf ("%s: %s",
-				       weather_info_get_location_name (info),
-				       weather_info_get_sky (info));
-            detail = g_strdup_printf (_("City: %s\nSky: %s\nTemperature: %s"),
-				      weather_info_get_location_name (info),
-				      weather_info_get_sky (info),
-				      weather_info_get_temp_summary (info));
-            
-	    NotifyNotification *n = notify_notification_new(message, detail,
-							    GTK_STOCK_INFO, 
-							    gw_applet->container);
-
-	    /* FIXME: emable this makes notify-daemon crash */
-/*             weather_info_get_pixbuf (gw_applet->gweather_info, &pixbuf); */
-/* 	    if (pixbuf) */
-/* 	       notify_notification_set_icon_data_from_pixbuf (n, pixbuf); */
-	    if (!notify_notification_show (n, NULL))
-	        g_warning ("Could not send notification to daemon\n");
-
-	    g_free (message);
-	    g_free (detail);
+		    if (notify_is_initted ())
+		    {
+			 GError *error = NULL;
+			 
+	           	 /* Show notification */
+	           	 message = g_strdup_printf ("%s: %s",
+					 weather_info_get_location_name (info),
+					 weather_info_get_sky (info));
+	           	 detail = g_strdup_printf (
+					 _("City: %s\nSky: %s\nTemperature: %s"),
+					 weather_info_get_location_name (info),
+					 weather_info_get_sky (info),
+					 weather_info_get_temp_summary (info));
+	           	 
+			 n = notify_notification_new (message, detail, NULL,
+					 gw_applet->container);
+	
+			 /* set the pixbuf */
+	           	 weather_info_get_pixbuf (gw_applet->gweather_info,
+					 &pixbuf);
+	 	   	 if (pixbuf)
+	 	   	    notify_notification_set_icon_from_pixbuf (n, pixbuf);
+		   	 notify_notification_show (n, &error);
+			 if (error)
+			 {
+				 g_warning (error->message);
+				 g_error_free (error);
+			 }
+		   	     
+		   	 g_free (message);
+		   	 g_free (detail);
+		    }
+	    }
 #endif
     }
     else
